@@ -77,18 +77,18 @@ def isInstanceInProcess(name, klass, process, shell):
 # Get the keys() of a dictionary in the process
 @process_task
 def getKeysInProcess(name, process, shell):
-        try:
-            return list(get_env(shell.user_ns)[name].keys())
-        except:
-            return None
+    try:
+        return list(get_env(shell.user_ns)[name].keys())
+    except:
+        return None
 
 # Get the columns of a Pandas data frame in the process
 @process_task
 def getColumnsInProcess(name, process, shell):
-        try:
-            return list(get_env(shell.user_ns)[name].columns)
-        except:
-            return None
+    try:
+        return list(get_env(shell.user_ns)[name].columns)
+    except:
+        return None
 
 # Is a key defined in a collection in the process?
 @process_task
@@ -328,8 +328,8 @@ def get_error(f, *args, **kwargs):
 # Eval an expression tree or node (with setting envs, pre_code and/or expr_code)
 @process_task
 def taskRunEval(tree,
-                process, shell, 
-                keep_objs_in_env = None, extra_env = None, context=None, context_vals=None, 
+                process, shell,
+                env=None, extra_env = None, context=None, context_vals=None,
                 pre_code = "", expr_code = "", name="", copy=True, tempname='_evaluation_object_', 
                 do_exec=False, call=None):
     try: 
@@ -351,8 +351,10 @@ def taskRunEval(tree,
         if not copy or (isinstance(tree, ast.Name) and isinstance(tree.ctx, ast.Load)):
             new_env = dict(get_env(shell.user_ns))
         else:
-            new_env = utils.copy_env(get_env(shell.user_ns), keep_objs_in_env)
+            new_env = utils.copy_env(get_env(shell.user_ns))
 
+        if env is not None:
+            new_env.update(deepcopy(env))
         if extra_env is not None:
             new_env.update(deepcopy(extra_env))
         if context is not None: 
